Package: contentanalysis
Title: Scientific Content and Citation Analysis from PDF Documents
Version: 1.1.0
Authors@R: c(
    person(given = "Massimo",
           family = "Aria",
           role = c("cre", "aut", "cph"),
           email = "aria@unina.it",
           comment = c(ORCID = "0000-0002-8517-9411")),
    person(given = "Corrado", 
           family = "Cuccurullo", 
           role = "aut",
           email = "cuccurullocorrado@gmail.com",
           comment = c(ORCID = "0000-0002-7401-8575")))
Description: Provides comprehensive tools for extracting and analyzing scientific 
    content from PDF documents, including citation extraction, reference matching, 
    text analysis, and bibliometric indicators. Supports multi-column PDF layouts,
    'CrossRef' API <https://www.crossref.org/documentation/retrieve-metadata/rest-api/> integration, and advanced citation parsing.
License: GPL (>= 3)
Encoding: UTF-8
Depends: R (>= 4.1.0)
Imports: base64enc (>= 0.1-3), dplyr (>= 1.1.0), httr2 (>= 0.2.0),
        igraph, jsonlite (>= 2.0.0), magrittr (>= 2.0.4), openalexR (>=
        2.0.2), pdftools (>= 3.6.0), purrr (>= 1.1.0), stringr (>=
        1.5.2), tibble (>= 3.3.0), tidyr (>= 1.3.0), tidytext (>=
        0.4.3), visNetwork (>= 2.1.4)
Suggests: knitr, plotly, RColorBrewer, rmarkdown, scales, stringdist,
        testthat (>= 3.0.0), mockery
URL: https://github.com/massimoaria/contentanalysis,
BugReports: https://github.com/massimoaria/contentanalysis/issues
VignetteBuilder: knitr
Config/testthat/edition: 3
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-19 15:22:29 UTC; massimoaria
Author: Massimo Aria [cre, aut, cph] (ORCID:
    <https://orcid.org/0000-0002-8517-9411>),
  Corrado Cuccurullo [aut] (ORCID:
    <https://orcid.org/0000-0002-7401-8575>)
Maintainer: Massimo Aria <aria@unina.it>
Repository: CRAN
Date/Publication: 2026-05-19 15:50:02 UTC
Built: R 4.4.3; ; 2026-05-19 17:52:14 UTC; unix
