# Generated by roxygen2: do not edit by hand

S3method(print,rhetorical_move_analysis)
export("%>%")
export(analyze_scientific_content)
export(calculate_readability_indices)
export(calculate_word_distribution)
export(classify_rhetorical_moves)
export(create_citation_network)
export(describe_citation_clusters)
export(extract_doi_from_pdf)
export(extract_pdf_metadata)
export(gemini_content_ai)
export(get_crossref_references)
export(get_example_paper)
export(map_citations_to_segments)
export(match_citations_to_references)
export(merge_text_chunks_named)
export(normalize_references_section)
export(parse_references_section)
export(pdf2txt_auto)
export(pdf2txt_multicolumn_safe)
export(plot_citation_clusters)
export(plot_word_distribution)
export(process_large_pdf)
export(readability_multiple)
export(split_into_sections)
import(dplyr)
import(stringr)
import(visNetwork)
importFrom(base64enc,base64encode)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,desc)
importFrom(dplyr,distinct)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,rename)
importFrom(dplyr,row_number)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,slice_head)
importFrom(dplyr,summarize)
importFrom(dplyr,ungroup)
importFrom(grDevices,col2rgb)
importFrom(httr2,req_body_json)
importFrom(httr2,req_headers)
importFrom(httr2,req_perform)
importFrom(httr2,req_url_query)
importFrom(httr2,req_user_agent)
importFrom(httr2,request)
importFrom(httr2,resp_body_json)
importFrom(igraph,layout_nicely)
importFrom(jsonlite,fromJSON)
importFrom(magrittr,"%>%")
importFrom(openalexR,oa_fetch)
importFrom(pdftools,pdf_data)
importFrom(pdftools,pdf_info)
importFrom(pdftools,pdf_length)
importFrom(pdftools,pdf_subset)
importFrom(pdftools,pdf_text)
importFrom(pdftools,pdf_toc)
importFrom(pdftools,poppler_config)
importFrom(purrr,map_dfr)
importFrom(purrr,map_lgl)
importFrom(stats,kmeans)
importFrom(stats,na.omit)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(stringr,str_count)
importFrom(stringr,str_detect)
importFrom(stringr,str_extract)
importFrom(stringr,str_extract_all)
importFrom(stringr,str_length)
importFrom(stringr,str_locate_all)
importFrom(stringr,str_match)
importFrom(stringr,str_remove)
importFrom(stringr,str_replace)
importFrom(stringr,str_replace_all)
importFrom(stringr,str_split)
importFrom(stringr,str_squish)
importFrom(stringr,str_sub)
importFrom(stringr,str_to_lower)
importFrom(stringr,str_to_title)
importFrom(stringr,str_trim)
importFrom(stringr,str_trunc)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,replace_na)
importFrom(tidytext,bind_tf_idf)
importFrom(tidytext,unnest_tokens)
importFrom(utils,data)
importFrom(utils,download.file)
importFrom(utils,head)
