#' @importFrom utils data head download.file
#' @importFrom stats setNames
#' @importFrom dplyr row_number
NULL

utils::globalVariables(c(
  "start_pos",
  "citation_text",
  "citation_type",
  "author_part",
  "year_part",
  "citation_id",
  "standardized_citation",
  "word",
  "stop_words",
  "ngram",
  "segment",
  "section",
  "total_citations",
  "original_complex_citation",
  "author",
  "year",
  "article_title",
  "journal",
  "ref_first_author",
  "ref_id",
  "ref_full_text",
  "ref_authors",
  "ref_year",
  "ref_first_author_normalized",
  "n_authors",
  "citation_text_clean",
  "matched_ref_id",
  "match_confidence",
  "cite_info",
  "ref_second_author_normalized",
  "cite_author",
  "cite_second_author",
  "cite_year",
  "cite_has_etal",
  "authors_section",
  "ref_second_author",
  "segment_id",
  "segment_name",
  "segment_type",
  "ngram_size",
  "total_words",
  "relative_frequency",
  "segment_name.x",
  "segment_name.y",
  "n",
  ".",
  "ref_source",
  "ref_first_author_surname",
  "citation",
  "citation1",
  "citation2",
  "distance",
  "font.size",
  "n_sections",
  "primary_section",
  "sections",
  "size",
  "median",
  "ref_full",
  "ref_full_text2",
  "ref_journal",
  "citation_numbers",
  "get_surname",
  "ref_first_author_normalized_no_accents",
  "tf",
  "idf",
  "tf_idf",
  "ref_title",
  "ref_title_clean",
  "top_terms",
  "n_references",
  "sentence_id",
  "position_pct",
  "move",
  "step",
  "confidence",
  "method",
  "move_rule",
  "step_rule",
  "conf_rule",
  "move_llm",
  "step_llm",
  "conf_llm",
  "block_id",
  "text_preview",
  "avg_confidence",
  "n_sentences",
  "start_sentence",
  "end_sentence",
  "taxonomy_type",
  "pct"
))
