% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pdf2txtAI.R
\name{remove_code_blocks}
\alias{remove_code_blocks}
\title{Remove Markdown Code Block Markers}
\usage{
remove_code_blocks(text)
}
\arguments{
\item{text}{Character string containing markdown text}
}
\value{
Character string with \verb{markdown and } markers removed
}
\description{
Remove Markdown Code Block Markers
}
