% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/readability_indices.R
\name{create_empty_readability_tibble}
\alias{create_empty_readability_tibble}
\title{Create empty readability tibble}
\usage{
create_empty_readability_tibble(detailed = FALSE)
}
\arguments{
\item{detailed}{Logical, if TRUE includes detailed statistics columns}
}
\value{
Tibble with NA values
}
\description{
Creates an empty tibble with NA values for readability indices.
}
\keyword{internal}
