% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rhetorical_moves.R
\name{print.rhetorical_move_analysis}
\alias{print.rhetorical_move_analysis}
\title{Print method for rhetorical move analysis}
\usage{
\method{print}{rhetorical_move_analysis}(x, ...)
}
\arguments{
\item{x}{A rhetorical_move_analysis object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns x
}
\description{
Print method for rhetorical move analysis
}
